local _G = getfenv(0)

local moduleName = "party"


local L = AceLibrary('AceLocale-2.2'):new('SimpleUnitFrames_Party')

L:RegisterTranslations('enUS', function() return {

	["Party Frame"] = true,
	["Description"] = "Options for the party frame",
	["Middle Health Text"] = true,
	["Right Health Text"] = true,
	["Middle Mana Text"] = true,
	["Right Mana Text"] = true,
	["Middle Health Text Description"] = "Set middle health text to one of the formats",
	["Right Health Text Description"] = "Set right health text to one of the formats",
	["Middle Mana Text Description"] = "Set middle mana text to one of the formats",
	["Right Mana Text Description"] = "Set right health text to one of the formats",
	
} end)

L:RegisterTranslations('koKR', function() return {

	["Description"] = "파티 프레임에 대한 설정",
	
	["Middle Health Text"] = "중간 생명력 글자",
	["Right Health Text"] = "오른쪽 생명력 글자",
	["Middle Mana Text"] = "중간 마나 글자",
	["Right Mana Text"] = "오른쪽 마나 글자",
	["Middle Health Text Description"] = "중간 생명력 글자 표시 방법 선택",
	["Right Health Text Description"] = "오른쪽 생명력 글자 표시 방법 선택",
	["Middle Mana Text Description"] = "중간 마나 글자 표시 방법 선택",
	["Right Mana Text Description"] = "오른쪽 마나 글자 표시 방법 선택",
	
} end)

local Party = SimpleUnitFrames:NewModule(moduleName, "AceEvent-2.0")

Party.core.defaults[moduleName] = {
	mhp = "percenthp",
	rhp = "currmaxhp",
	mmp = "percentmp",
	rmp = "currmaxmp",
}

local OPTION_ORDER = 100
Party.consoleOptions = {
	type = 'group',
	name = L['Party Frame'],
	desc = L['Description'],
	args = {	
		mhp = {
			order = OPTION_ORDER + 1,
			type = 'text',
			name = L['Middle Health Text'],
			desc = L['Middle Health Text Description'],
			get = function() return Party.db.mhp end,
			set = function(v) 
							Party.db.mhp = v
							Party:Refresh()
						end,
			validate = Party.core.formatList,
		},
		rhp = {
			order = OPTION_ORDER + 2,
			type = 'text',
			name = L['Right Health Text'],
			desc = L['Right Health Text Description'],
			get = function() return Party.db.rhp end,
			set = function(v) 
							Party.db.rhp = v
							Party:Refresh()
						end,
			validate = Party.core.formatList,
		},
		mmp = {
			order = OPTION_ORDER + 3,
			type = 'text',
			name = L['Middle Mana Text'],
			desc = L['Middle Mana Text Description'],
			get = function() return Party.db.mmp end,
			set = function(v)
							Party.db.mmp = v
							Party:Refresh()
						end,
			validate = Party.core.formatList,
		},
		rmp = {
			order = OPTION_ORDER + 4,
			type = 'text',
			name = L['Right Mana Text'],
			desc = L['Right Mana Text Description'],
			get = function() return Party.db.rmp end,
			set = function(v)
							Party.db.rmp = v
							Party:Refresh()
						end,
			validate = Party.core.formatList,
		},
	}
}



function Party:OnInitialize()


end



function Party:OnShow()

	if self.db then
		self:RegisterEvent("PARTY_MEMBERS_CHANGED", "Refresh");
		self:RegisterEvent("UNIT_HEALTH", "OnHealthChange" )
		self:RegisterEvent("UNIT_MAXHEALTH", "OnHealthChange" )
		self:RegisterEvent("UNIT_MANA", "OnManaChange" )
		self:RegisterEvent("UNIT_MAXMANA", "OnManaChange")
		self:RegisterEvent("UNIT_ENERGY", "OnManaChange")
		self:RegisterEvent("UNIT_MAXENERGY", "OnManaChange")
		self:RegisterEvent("UNIT_RAGE", "OnManaChange")
		self:RegisterEvent("UNIT_MAXRAGE", "OnManaChange")
		self:RegisterEvent("UNIT_DISPLAYPOWER", "OnManaChange")		
		self:Refresh()
	end

end

function Party:OnHide()

	self:UnregisterAllEvents()
	
end

function Party:Refresh()
	for i=1, GetNumPartyMembers(), 1 do
		local unitid = 'party' .. i
		if UnitExists(unitid) then
			self:UpdateHealth(unitid)
			self:UpdateMana(unitid)
		end
	end
end

function Party:OnHealthChange(arg1)
	if string.find(arg1, '^party%d$') then
		self:UpdateHealth(arg1)
	end
end

function Party:OnManaChange(arg1)
	if string.find(arg1, '^party%d$') then
		self:UpdateMana(arg1)
	end
end
		

function Party:UpdateHealth(unitid)
	local i = string.sub(unitid, 6, 6)
	_G['SUF_PartyFrame'.. i .. 'HealthMiddle' ]:SetText( self:GetValueText(unitid, self.db.mhp) )
	_G['SUF_PartyFrame'.. i .. 'HealthRight' ]:SetText( self:GetValueText(unitid, self.db.rhp) )
end

function Party:UpdateMana(unitid)
	local i = string.sub(unitid, 6, 6)
	_G['SUF_PartyFrame'.. i .. 'ManaMiddle' ]:SetText( self:GetValueText(unitid, self.db.mmp) )
	_G['SUF_PartyFrame'.. i .. 'ManaRight' ]:SetText( self:GetValueText(unitid, self.db.rmp) )
end

-- Global name for PartyFrame to reach.
SUF_Party = Party